translate.filters.prefilters

Package translate :: Package filters :: Module prefilters |
[hide private]
[frames] | no frames]

# Module prefilters

source code

This is a set of string filters that strings can be passed through before certain tests.

Functions | [hide private]
removekdecomments(str1) removed kde-style po comments i.e. | source code
filteraccelerators(accelmarker) returns a function that filters accelerators marked using accelmarker in strings | source code
varname(variable, startmarker, endmarker) a simple variable filter that returns the variable name without the marking punctuation | source code
varnone(variable, startmarker, endmarker) a simple variable filter that returns an emoty string | source code
filtervariables(startmarker, endmarker, varfilter) returns a function that filters variables marked using startmarker and endmarker in strings | source code
filterwordswithpunctuation(str1) goes through a list of known words that have punctuation and removes the punctuation from them | source code

Variables | [hide private]
| wordswithpunctuation = ``{``'``\'n``'``:` `'``n``'``,` `'``\'t``'``:` `'``t``'``}``
| word_with_apos_re = `re.compile(r'`(?u)`\w`+`\'\w`+`')`
| __package__ = ``'``translate.filters``'``
| word = ``'``\'t``'``

Imports: re, decoration, quote

Function Details | [hide private]

### removekdecomments(str1) | source code
removed kde-style po comments i.e. starting with _: and ending with litteral \n